==> deep_code-0.1.4.dev1.tar.gz: deep_code-0.1.4.dev1/deep_code/constants.py <==
#!/usr/bin/env python3

# Copyright (c) 2024 by Brockmann Consult GmbH
# Permissions are hereby granted under the terms of the MIT License:
# https://opensource.org/licenses/MIT.

OSC_SCHEMA_URI = "https://stac-extensions.github.io/osc/v1.0.0/schema.json"
CF_SCHEMA_URI = "https://stac-extensions.github.io/cf/v0.2.0/schema.json"
THEMES_SCHEMA_URI = "https://stac-extensions.github.io/themes/v1.0.0/schema.json"
OSC_THEME_SCHEME = "https://github.com/stac-extensions/osc#theme"
OSC_REPO_OWNER = "ESA-EarthCODE"
OSC_REPO_NAME = "open-science-catalog-metadata"
OSC_BRANCH_NAME = "add-new-collection"
DEFAULT_THEME_SCHEME = (
    "https://gcmd.earthdata.nasa.gov/kms/concepts/concept_scheme/sciencekeywords"
)
OGC_API_RECORD_SPEC = "http://www.opengis.net/spec/ogcapi-records-1/1.0/req/record-core"
WF_BRANCH_NAME = "add-new-workflow-from-deepesdl"
VARIABLE_BASE_CATALOG_SELF_HREF = "https://esa-earthcode.github.io/open-science-catalog-metadata/variables/catalog.json"
PRODUCT_BASE_CATALOG_SELF_HREF = "https://esa-earthcode.github.io/open-science-catalog-metadata/products/catalog.json"
DEEPESDL_COLLECTION_SELF_HREF = (
    "https://esa-earthcode.github.io/open-science-catalog-metadata/projects/deepesdl"
    "/collection.json"
)
BASE_URL_OSC = "https://esa-earthcode.github.io/open-science-catalog-metadata"
EXPERIMENT_BASE_CATALOG_SELF_HREF = "https://esa-earthcode.github.io/open-science-catalog-metadata/experiments/catalog.json"
WORKFLOW_BASE_CATALOG_SELF_HREF = (
    "https://esa-earthcode.github.io/open-science-catalog-metadata/workflows/catalog"
    ".json"
)
PROJECT_COLLECTION_NAME = "deep-earth-system-data-lab"

==> deep_code-0.1.6.tar.gz: deep_code-0.1.6/deep_code/constants.py <==
#!/usr/bin/env python3

# Copyright (c) 2024 by Brockmann Consult GmbH
# Permissions are hereby granted under the terms of the MIT License:
# https://opensource.org/licenses/MIT.

OSC_SCHEMA_URI = "https://stac-extensions.github.io/osc/v1.0.0/schema.json"
CF_SCHEMA_URI = "https://stac-extensions.github.io/cf/v0.2.0/schema.json"
THEMES_SCHEMA_URI = "https://stac-extensions.github.io/themes/v1.0.0/schema.json"
OSC_THEME_SCHEME = "https://github.com/stac-extensions/osc#theme"
OSC_REPO_OWNER = "ESA-EarthCODE"
OSC_REPO_NAME = "open-science-catalog-metadata"
OSC_BRANCH_NAME = "add-new-collection"
DEFAULT_THEME_SCHEME = (
    "https://gcmd.earthdata.nasa.gov/kms/concepts/concept_scheme/sciencekeywords"
)
OGC_API_RECORD_SPEC = "http://www.opengis.net/spec/ogcapi-records-1/1.0/req/record-core"
WF_BRANCH_NAME = "add-new-workflow-from-deepesdl"
VARIABLE_BASE_CATALOG_SELF_HREF = "https://esa-earthcode.github.io/open-science-catalog-metadata/variables/catalog.json"
PRODUCT_BASE_CATALOG_SELF_HREF = "https://esa-earthcode.github.io/open-science-catalog-metadata/products/catalog.json"
DEEPESDL_COLLECTION_SELF_HREF = (
    "https://esa-earthcode.github.io/open-science-catalog-metadata/projects/deepesdl"
    "/collection.json"
)
BASE_URL_OSC = "https://esa-earthcode.github.io/open-science-catalog-metadata"
EXPERIMENT_BASE_CATALOG_SELF_HREF = "https://esa-earthcode.github.io/open-science-catalog-metadata/experiments/catalog.json"
WORKFLOW_BASE_CATALOG_SELF_HREF = (
    "https://esa-earthcode.github.io/open-science-catalog-metadata/workflows/catalog"
    ".json"
)
PROJECT_COLLECTION_NAME = "deep-earth-system-data-lab"
DEEPESDL_GIT_PULL_BASE = (
    "https://deep.earthsystemdatalab.net/hub/user-redirect/git-pull"
)
APPLICATION_TYPE_JUPYTER_SPEC = (
    "https://raw.githubusercontent.com/EOEPCA/metadata"
    "-profile/refs/heads/1.0/schemas/application-type-jupyter-notebook"
)
APPLICATION_STAC_EXTENSION_SPEC = (
    "https://stac-extensions.github.io/application/v0.1.0/schema.json"
)
